<?php

	// 設定項目
	$request_url = 'https://api.moves-app.com/api/1.1/user/summary/daily/' . date( 'Ym' ) ;	// リクエストURL
	$access_token = '' ;	// アクセストークン

	// リクエストURLにアクセストークンを結合
	$is_param = explode( '?' , $request_url ) ;
	$request_url .= ( ( isset( $is_param[1] ) && !empty( $is_param[1] ) ) ? '&' : '?' ) . 'access_token=' . $access_token ;
   
	// JSONデータを取得する
	$curl = curl_init() ;
	curl_setopt( $curl , CURLOPT_URL , $request_url ) ;
	curl_setopt( $curl , CURLOPT_HEADER, 1 ) ; 
	curl_setopt( $curl , CURLOPT_SSL_VERIFYPEER , false ) ;								// 証明書の検証を行わない
	curl_setopt( $curl , CURLOPT_RETURNTRANSFER , true ) ;								// curl_execの結果を文字列で返す
	curl_setopt( $curl , CURLOPT_TIMEOUT , 5 ) ;										// タイムアウトの秒数
	$res1 = curl_exec( $curl ) ;
	$res2 = curl_getinfo( $curl ) ;
	curl_close( $curl ) ;

	// 取得したデータ
	$json = substr( $res1, $res2['header_size'] ) ;										// 取得したデータ(JSONなど)
	$header = substr( $res1, 0, $res2['header_size'] ) ;								// レスポンスヘッダー (検証に利用したい場合にどうぞ)

	// オブジェクトに変換する
	$obj = json_decode( $json ) ;

	// 記録用配列の初期値
	$data = array(
		'walking' => array(
			'label' => 'ウォーキング' ,
			'duration' => 0 ,
			'distance' => 0 ,
			'steps' => 0 ,
		) ,
		'running' => array(
			'label' => 'ランニング' ,
			'duration' => 0 ,
			'distance' => 0 ,
			'steps' => 0 ,
		) ,
		'cycling' => array(
			'label' => 'サイクリング' ,
			'duration' => 0 ,
			'distance' => 0 ,
		) ,
	) ;

	// HTML用
	$html = '' ;

	// エラー判定
	if( !$obj )
	{
		$html .= '<p>データを取得できませんでした…。</p>' ;
	}
	else
	{
		// 日ごとの解析
		foreach( $obj as $summary )
		{
			// 内容がなければスキップ
			if( !isset($summary->summary) || empty($summary->summary) )
			{
				continue ;
			}

			// サマリーの解析
			foreach( $summary->summary as $item )
			{
				// 運動カテゴリ
				$group = $item->group ;

				// 歩き、走り、自転車のみ記録
				if( $group == 'transport' )
				{
					continue ;
				}

				// 時間(秒)・距離(メートル)・歩数を合計していく
				$data[ $group ]['duration'] += $item->duration ;
				$data[ $group ]['distance'] += $item->distance ;

				// 歩数がある場合
				if( isset($item->steps) )
				{
					$data[ $group ]['steps'] += $item->steps ;
				}
			}
		}

		// HTMLを作成
		$html .= '<h2>今月(' . date( 'n' ) . '月)の運動記録</h2>' ;

		// 運動項目ごとのデータを出力
		foreach( $data as $item )
		{
			$html .= 	'<h3>' . $item['label'] . '</h3>' ;
			$html .= 	'<dl>' ;
			$html .= 		'<dt>合計時間</dt>' ;
			$html .= 			'<dd>' . $item['duration'] . '秒</dd>' ;
			$html .= 		'<dt>合計距離</dt>' ;
			$html .= 			'<dd>' . $item['distance'] . 'メートル</dd>' ;

			// 歩数がある場合
			if( isset($item['steps']) && !empty($item['steps']) )
			{
				$html .= 		'<dt>合計歩数</dt>' ;
				$html .= 			'<dd>' . $item['steps'] . '歩</dd>' ;
			}

			$html .= 	'</dl>' ;
		}
	}

?><!DOCTYPE html>
<html>
	<head>
		<meta charset="UTF-8">
		<meta name="robots" content="noindex,nofollow">

		<!-- ビューポートの設定 -->
		<meta name="viewport" content="width=device-width, initial-scale=1.0">

		<title>Moves APIで今月の運動記録を表示するサンプルデモ</title><!-- 

/********************************************************************************

	SYNCER 〜 知識、感動をみんなと同期(Sync)するブログ

	* 配布場所
	https://syncer.jp/moves-api-matome

	* 動作確認
	https://syncer.jp/moves-api-matome/demo/moves-idea-01.php

	* 最終更新日時
	2015/08/03 04:00

	* 作者
	あらゆ

	** 連絡先
	Twitter: https://twitter.com/arayutw
	Facebook: https://www.facebook.com/arayutw
	Google+: https://plus.google.com/114918692417332410369/
	E-mail: info@syncer.jp

	※ バグ、不具合の報告、提案、ご要望など、お待ちしております。
	※ 申し訳ありませんが、ご利用者様、個々の環境における問題はサポートしていません。

********************************************************************************/

		-->
	</head>
<body>



<?php echo $html ?>


<p style="text-align:center"><a href="https://syncer.jp/moves-api-matome">配布元: Syncer</a></p>






</body>
</html>
