<?php

	// 設定項目
	$request_url = 'https://api.moves-app.com/api/v1/user/storyline/daily/' . date( 'Ymd' ) . '?trackPoints=true' ;	// リクエストURL
	$access_token = '' ;	// アクセストークン
	$skip_home = 1 ;		// 1=ホームに滞在している時の位置情報を避ける、0=避けない
	$skip_work = 1 ;		// 1=職場に滞在している時の位置情報を避ける、0=避けない
	$skip_school = 1 ;		// 1=学校に滞在している時の位置情報を避ける、0=避けない

	// リクエストURLにアクセストークンを結合
	$is_param = explode( '?' , $request_url ) ;
	$request_url .= ( ( isset( $is_param[1] ) && !empty( $is_param[1] ) ) ? '&' : '?' ) . 'access_token=' . $access_token ;
   
	// JSONデータを取得する
	$curl = curl_init() ;
	curl_setopt( $curl , CURLOPT_URL , $request_url ) ;
	curl_setopt( $curl , CURLOPT_HEADER, 1 ) ; 
	curl_setopt( $curl , CURLOPT_SSL_VERIFYPEER , false ) ;								// 証明書の検証を行わない
	curl_setopt( $curl , CURLOPT_RETURNTRANSFER , true ) ;								// curl_execの結果を文字列で返す
	curl_setopt( $curl , CURLOPT_TIMEOUT , 5 ) ;										// タイムアウトの秒数
	$res1 = curl_exec( $curl ) ;
	$res2 = curl_getinfo( $curl ) ;
	curl_close( $curl ) ;

	// 取得したデータ
	$json = substr( $res1, $res2['header_size'] ) ;										// 取得したデータ(JSONなど)
	$header = substr( $res1, 0, $res2['header_size'] ) ;								// レスポンスヘッダー (検証に利用したい場合にどうぞ)

	// オブジェクトではなく、配列に変換する
	$array = json_decode( $json , 1 ) ;

	// 出力用の変数
	$html = '' ;	// HTML用

	// エラー判定
	if( !$array )
	{
		$html .= '<h2>実行結果</h2>' ;
		$html .= '<p>データを取得できませんでした…。</p>' ;
	}
	else
	{
		// 見出し
		$html .= '<h2>リアルタイム地図</h2>' ;

		// データがある場合のみ解析処理
		if( isset($array[0]['segments']) && !empty($array[0]['segments']) )
		{
			// ストーリーラインの配列を[昔→今]から[今→昔]に並び替え
			krsort( $array[0]['segments'] ) ;

			// 全てのトラックポイントを取得していく
			foreach( $array[0]['segments'] as $item )
			{
				// 最終時刻の記録
				if( isset($item['endTime']) && !empty($item['endTime']) )
				{
					// 時刻を記録
					$time = $item['endTime'] ;
				}

				// 最新のセグメントが[場所]の場合
				if( $item['type'] == 'place')
				{
					// 自宅、会社、学校の場合はスキップ (有効設定の場合のみ)
					if( ( $item['place']['type'] == 'home' && $skip_home ) || ( $item['place']['type'] == 'work' && $skip_work ) || ( $item['place']['type'] == 'school' && $skip_school ) )
					{
						continue ;
					}

					// 場所の緯度・経度を配列[$geo]に格納
					$geo = array( $item['place']['location']['lat'] , $item['place']['location']['lon'] ) ;
				}

				// 最新のセグメントが[運動]の場合
				elseif( $item['type'] == 'move' || $item['type'] == 'off' )
				{
					// アクティビティの存在を確認
					if( isset( $item['activities'][0] ) )
					{
						// アクティビティの配列を[昔→今]から[今→昔]にする
						krsort( $item['activities'] ) ;

						// トラックポイントの解析
						foreach( $item['activities'] as $activities )
						{
							// トラックポイントの存在を確認
							if( isset( $activities['trackPoints'][0]['lat']) && isset( $activities['trackPoints'][0]['lon']) )
							{
								// トラックポイントの配列を[昔→今]から[今→昔]にする
								krsort( $activities['trackPoints'] ) ;

								// 解析
								foreach( $activities['trackPoints'] as $trackpoints )
								{
									// 最新の緯度・経度を配列[$geo]に格納
									if( isset( $trackpoints['lat'] ) && isset( $trackpoints['lon'] ) )
									{
										$geo = array( $trackpoints['lat'] , $trackpoints['lon'] ) ;
										break ;
									}
								}
							}

							// 最新の緯度・経度が取得できた時点でループ終了
							if( isset( $geo ) )
							{
								break ;
							}
						}
					}

					// 最新の緯度・経度が取得できた時点でループ終了
					if( isset($geo) )
					{
						break ;
					}
				}
			}
		}

		// 位置情報がない場合
		if( !isset( $geo ) || empty( $geo ) || !isset( $time ) || empty( $time ) )
		{
			$html .= '<p>今日はまだ、行動していないみたいです…。</p>' ;
		}

		// 位置情報がある場合
		else
		{
			// 緯度・経度を利用して、Google Static Mapsで地図を表示
			$html .= '<p>' . date( 'Y年n月j日のH時i分' , strtotime( $time ) ) . 'に、下記の位置にいました。</p>' ;
			$html .= '<p><img class="_img" src="http://maps.googleapis.com/maps/api/staticmap?size=640x480&markers=color:red%7C' . $geo[0] . ',' . $geo[1] . '&sensor=false"></p>' ;
		}
	}

?><!DOCTYPE html>
<html>
	<head>
		<meta charset="UTF-8">
		<meta name="robots" content="noindex,nofollow">

		<!-- ビューポートの設定 -->
		<meta name="viewport" content="width=device-width, initial-scale=1.0">

		<title>Moves APIを利用したリアルタイム地図のサンプルデモ</title><!-- 

/********************************************************************************

	SYNCER 〜 知識、感動をみんなと同期(Sync)するブログ

	* 配布場所
	https://syncer.jp/moves-api-matome

	* 動作確認
	https://syncer.jp/moves-api-matome/demo/moves-idea-03.php

	* 最終更新日時
	2015/08/03 04:01

	* 作者
	あらゆ

	** 連絡先
	Twitter: https://twitter.com/arayutw
	Facebook: https://www.facebook.com/arayutw
	Google+: https://plus.google.com/114918692417332410369/
	E-mail: info@syncer.jp

	※ バグ、不具合の報告、提案、ご要望など、お待ちしております。
	※ 申し訳ありませんが、ご利用者様、個々の環境における問題はサポートしていません。

********************************************************************************/

		-->
	</head>
<body>



<?php echo $html ?>


<p style="text-align:center"><a href="https://syncer.jp/moves-api-matome">配布元: Syncer</a></p>






</body>
</html>
