<?php

	// 設定項目
	$client_id = '' ;				// クライアントID
	$client_secret = '' ;		// クライアントシークレット
	$redirect_uri = ( !isset($_SERVER['HTTPS']) || empty($_SERVER['HTTPS']) ? 'http://' : 'https://' ) . $_SERVER['HTTP_HOST'] . $_SERVER['REQUEST_URI'] ;		// このプログラムを設置するURL
 	$scope = 'activity location' ;			// アプリの権限

	// セッションスタート
	session_start() ;

	// HTML用
	$html = '' ;

	// アプリ認証から帰ってきた場合はアクセストークンを取得
	if( isset($_GET['code']) && is_string($_GET['code']) )
	{
		// セッションにCSRF対策用の[state]がない場合は不正と判断してエラー
		if( !isset($_SESSION['state']) || empty($_SESSION['state']) )
		{
			$error = 'セッションが上手く機能してないかもしれません。' ;
		}

		// CSRF対策
		elseif( !isset($_GET['state']) || empty($_GET['state']) || $_GET['state'] != $_SESSION['state'] )
		{
			$error = 'セッションに保存してあるstateと、返ってきたstateの値が違います…。' ;
		}

		// アクセストークンの取得
		else
		{
			// リクエスト用のコンテキストを作成
			$context = array(
				'http' => array(
					'method' => 'POST' ,
					'content' => http_build_query( array(
						'grant_type' => 'authorization_code' ,
						'code' => $_GET['code'] ,
						'client_id' => $client_id ,
						'client_secret' => $client_secret ,
						'redirect_uri' => $redirect_uri ,
					) ) ,
				) ,
			) ;

			// CURLを使ってリクエスト
			$curl = curl_init() ;

			// オプションのセット
			curl_setopt( $curl , CURLOPT_URL , 'https://api.moves-app.com/oauth/v1/access_token' ) ;
			curl_setopt( $curl , CURLOPT_HEADER, 1 ) ; 
			curl_setopt( $curl , CURLOPT_CUSTOMREQUEST , $context['http']['method'] ) ;			// メソッド
			curl_setopt( $curl , CURLOPT_SSL_VERIFYPEER , false ) ;								// 証明書の検証を行わない
			curl_setopt( $curl , CURLOPT_RETURNTRANSFER , true ) ;								// curl_execの結果を文字列で返す
			curl_setopt( $curl , CURLOPT_POSTFIELDS , $context['http']['content'] ) ;			// リクエストボディ
			curl_setopt( $curl , CURLOPT_TIMEOUT , 5 ) ;										// タイムアウトの秒数

			// 実行
			$res1 = curl_exec( $curl ) ;
			$res2 = curl_getinfo( $curl ) ;

			// 終了
			curl_close( $curl ) ;

			// 取得したデータ
			$json = substr( $res1, $res2['header_size'] ) ;										// 取得したデータ(JSONなど)
			$header = substr( $res1, 0, $res2['header_size'] ) ;								// レスポンスヘッダー (検証に利用したい場合にどうぞ)

			// JSONをオブジェクトに変換
			$obj = json_decode( $json ) ;

			// アクセストークンが取得できない場合はエラー
			if( !isset($obj->access_token) || empty($obj->access_token) )
			{
				$error = 'アクセストークンを取得できませんでした…。' ;
			}
			else
			{
				// 各データを整理
				$user_id = $obj->user_id ;				// ユーザーID
				$access_token = $obj->access_token ;	// アクセストークン
				$refresh_token = $obj->refresh_token ;	// リフレッシュトークン
				$expires_in = $obj->expires_in ;		// アクセストークンの有効期限

				// 出力する
				$html .= '<h2>実行結果</h2>' ;
				$html .= '<dl>' ;
				$html .=  	'<dt>ユーザーID</dt>' ;
				$html .=  		'<dd>' . $user_id . '</dd>' ;
				$html .=  	'<dt>アクセストークン</dt>' ;
				$html .=  		'<dd>' . $access_token . '</dd>' ;
				$html .=  	'<dt>リフレッシュトークン</dt>' ;
				$html .=  		'<dd>' . $refresh_token . '</dd>' ;
				$html .=  	'<dt>アクセストークンの有効期限 (残りの秒数)</dt>' ;
				$html .=  		'<dd>' . $expires_in . ' (' . date( 'Y/m/d H:i:s' , ( time() + $expires_in ) ) . ' まで)' . '</dd>' ;
				$html .=  '</dl>' ;
			}
		}

		// 出力する
		$html .= '<h2>取得したデータ</h2>' ;
		$html .= '<p>下記のデータを取得しました。</p>' ;
		$html .= 	'<h3>JSON</h3>' ;
		$html .= 	'<p><textarea rows="8">' . $json . '</textarea></p>' ;
		$html .= 	'<h3>レスポンスヘッダー</h3>' ;
		$html .= 	'<p><textarea rows="8">' . $header . '</textarea></p>' ;

		// セッション終了
		$_SESSION = array() ;
		session_destroy() ;
	}

	// 初回アクセスの場合
	else
	{
		// CSRF対策
		session_regenerate_id( true ) ;
		$state = sha1( uniqid( mt_rand() , true ) ) ;
		$_SESSION['state'] = $state ;

		// ユーザーをアプリ認証画面へアクセス(リダイレクト)させる
		header( 'Location: https://api.moves-app.com/oauth/v1/authorize?response_type=code&client_id=' . $client_id . '&state=' . $state . '&scope=' . rawurlencode( $scope ) ) ;
	}

	// エラー時の処理
	if( isset($error) || !empty($error) )
	{
		$html = '<p><mark>' . $error . '</mark>もう一度、認証をするには、<a href="' . explode( '?' , $_SERVER['REQUEST_URI'] )[0] . '">こちら</a>をクリックして下さい。</p>' ;
	}

?><!DOCTYPE html>
<html>
	<head>
		<meta charset="UTF-8">
		<meta name="robots" content="noindex,nofollow">

		<!-- ビューポートの設定 -->
		<meta name="viewport" content="width=device-width, initial-scale=1.0">

		<title>Moves APIでOAuth認証をするサンプルデモ</title><!-- 

/********************************************************************************

	SYNCER 〜 知識、感動をみんなと同期(Sync)するブログ

	* 配布場所
	https://syncer.jp/moves-api-matome

	* 動作確認
	https://syncer.jp/moves-api-matome/demo/moves-oauth.php

	* 最終更新日時
	2015/08/03 03:48

	* 作者
	あらゆ

	** 連絡先
	Twitter: https://twitter.com/arayutw
	Facebook: https://www.facebook.com/arayutw
	Google+: https://plus.google.com/114918692417332410369/
	E-mail: info@syncer.jp

	※ バグ、不具合の報告、提案、ご要望など、お待ちしております。
	※ 申し訳ありませんが、ご利用者様、個々の環境における問題はサポートしていません。

********************************************************************************/

		-->
	</head>
<body>



<?php echo $html ?>


<p style="text-align:center"><a href="https://syncer.jp/moves-api-matome">配布元: Syncer</a></p>






</body>
</html>
