<?php

	// 設定項目
	$request_url = 'https://api.moves-app.com/api/1.1/user/storyline/daily?from=20150710&to=20150711&trackPoints=true' ;	// リクエストURL
	$access_token = '' ;	// アクセストークン

	// リクエストURLにアクセストークンを結合
	$is_param = explode( '?' , $request_url ) ;
	$request_url .= ( ( isset( $is_param[1] ) && !empty( $is_param[1] ) ) ? '&' : '?' ) . 'access_token=' . $access_token ;
   
	// JSONデータを取得する
	$curl = curl_init() ;
	curl_setopt( $curl , CURLOPT_URL , $request_url ) ;
	curl_setopt( $curl , CURLOPT_HEADER, 1 ) ; 
	curl_setopt( $curl , CURLOPT_SSL_VERIFYPEER , false ) ;								// 証明書の検証を行わない
	curl_setopt( $curl , CURLOPT_RETURNTRANSFER , true ) ;								// curl_execの結果を文字列で返す
	curl_setopt( $curl , CURLOPT_TIMEOUT , 5 ) ;										// タイムアウトの秒数
	$res1 = curl_exec( $curl ) ;
	$res2 = curl_getinfo( $curl ) ;
	curl_close( $curl ) ;

	// 取得したデータ
	$json = substr( $res1, $res2['header_size'] ) ;										// 取得したデータ(JSONなど)
	$header = substr( $res1, 0, $res2['header_size'] ) ;								// レスポンスヘッダー (検証に利用したい場合にどうぞ)

	// オブジェクトに変換する
	$obj = json_decode( $json ) ;

	// HTML用
	$html = '' ;

	// エラー判定
	if( !$obj )
	{
		$html .= '<p>データを取得できませんでした…。</p>' ;
	}
	else
	{
		// HTML
		$html .= '<h2>実行結果</h2>' ;
		$html .= '<p>下記の内容で取得しました。</p>' ;

		// ループ
		foreach( $obj as $segments )
		{
			// 1日ごとのストーリーラインを解析
			$html .= '<h3>' . $segments->date . '</h3>' ;

			foreach( $segments->segments as $item )
			{
				// 滞在場所の開始時間と終了時間
				$start = date( 'H:i' , strtotime( $item->startTime ) ) ;
				$end = date( 'H:i' , strtotime( $item->endTime ) ) ;

				// 時間ごとの記録
				$html .= '<h4>' . $start . '〜' . $end . '</h4>' ;

				// 場所の場合
				if( $item->type == 'place' )
				{
					//場所名・場所タイプ・緯度・経度
					$name = ( isset($item->place->name) && !empty($item->place->name) ) ? $item->place->name : '不明' ;	// 場所名
					$type = $item->place->type ;	// 場所タイプ
					$lat = $item->place->location->lat ;	// 緯度
					$lon = $item->place->location->lon ;	// 経度

					// 出力
					$html .= '<dl>' ;
					$html .= 	'<dt>名前</dt>' ;
					$html .= 		'<dd>' . $name . '</dd>' ;
					$html .= 	'<dt>場所タイプ</dt>' ;
					$html .= 		'<dd>' . $type . '</dd>' ;
					$html .= 	'<dt>緯度</dt>' ;
					$html .= 		'<dd>' . $lat . '</dd>' ;
					$html .= 	'<dt>経度</dt>' ;
					$html .= 		'<dd>' . $lon . '</dd>' ;
					$html .= '</dl>' ;
				}

				// 運動の場合
				elseif( $item->type == 'move' || $item->type == 'off' )
				{
					// 運動内容の解析
					foreach( $item->activities as $activity )
					{
						//運動項目・カテゴリ・時間(秒)・距離(メートル)・カロリー(kcal)・歩数
						$value = $activity->activity ;	// 運動項目
						$category = $activity->group ;	// 運動カテゴリ
						$duration = $activity->duration ;	// 時間(秒)
						$distance = $activity->distance ;	// 距離(メートル)
						$cal = ( isset($activity->calories) ) ? $activity->calories : '-' ;	// カロリー(kcal)
						$steps = ( isset($activity->steps) ) ? $activity->steps : '-' ;	// 歩数

						// トラックポイントを取得してる場合
						$tracks = '' ;

						if( isset( $activity->trackPoints ) )
						{
							// 個々のトラックポイントを取得
							foreach( $activity->trackPoints as $points )
							{
								//緯度・経度・時間(ついでに整形)
								$lat = $points->lat ;
								$lon = $points->lon ;
								$time = date( 'H:i:s' , strtotime($points->time) ) ;

								//変数[$traks]に格納
								$tracks .= '<li>' . $time . ' … ' . $lat . ',' . $lon . '</li>';
							}
						}

						// 出力
						$html .= '<dl>' ;
						$html .= 	'<dt>項目</dt>' ;
						$html .= 		'<dd>' . $value . '</dd>' ;
						$html .= 	'<dt>カテゴリ</dt>' ;
						$html .= 		'<dd>' . $category . '</dd>' ;
						$html .= 	'<dt>時間 (秒数)</dt>' ;
						$html .= 		'<dd>' . $duration . '</dd>' ;
						$html .= 	'<dt>距離 (メートル)</dt>' ;
						$html .= 		'<dd>' . $distance . '</dd>' ;
						$html .= 	'<dt>カロリー</dt>' ;
						$html .= 		'<dd>' . $cal . '</dd>' ;
						$html .= 	'<dt>歩数</dt>' ;
						$html .= 		'<dd>' . $steps . '</dd>' ;

						// トラックポイントがある場合
						if( $tracks )
						{
							$html .= 	'<dt>トラックポイント</dt>' ;
							$html .= 		'<dd><ul>' . $tracks . '</ul></dd>' ;
						}

						$html .= '</dl>' ;
					}
				}
			}
		}
	}

	// 取得したデータ
	$html .= '<h2>取得したデータ</h2>' ;
	$html .= '<p>下記のデータを取得できました。</p>' ;
	$html .= 	'<h3>JSON</h3>' ;
	$html .= 	'<p><textarea rows="8">' . $json . '</textarea></p>' ;
	$html .= 	'<h3>レスポンスヘッダー</h3>' ;
	$html .= 	'<p><textarea rows="8">' . $header . '</textarea></p>' ;

?><!DOCTYPE html>
<html>
	<head>
		<meta charset="UTF-8">
		<meta name="robots" content="noindex,nofollow">

		<!-- ビューポートの設定 -->
		<meta name="viewport" content="width=device-width, initial-scale=1.0">

		<title>Moves APIで指定期間のストーリーラインを取得するサンプルデモ</title><!-- 

/********************************************************************************

	SYNCER 〜 知識、感動をみんなと同期(Sync)するブログ

	* 配布場所
	https://syncer.jp/moves-api-matome

	* 動作確認
	https://syncer.jp/moves-api-matome/demo/storyline.php

	* 最終更新日時
	2015/08/03 03:55

	* 作者
	あらゆ

	** 連絡先
	Twitter: https://twitter.com/arayutw
	Facebook: https://www.facebook.com/arayutw
	Google+: https://plus.google.com/114918692417332410369/
	E-mail: info@syncer.jp

	※ バグ、不具合の報告、提案、ご要望など、お待ちしております。
	※ 申し訳ありませんが、ご利用者様、個々の環境における問題はサポートしていません。

********************************************************************************/

		-->
	</head>
<body>



<?php echo $html ?>


<p style="text-align:center"><a href="https://syncer.jp/moves-api-matome">配布元: Syncer</a></p>






</body>
</html>
